@@ -10,16 +10,16 @@ Kasa.ComT <- function (data,rank,k)
   equation = cajorls(cotest, r = rank , reg.number = NULL)
 
   alpha=matrix(NA,width,rank)
-  alpha [,1:rank] =equation$rlm$coefficients[1:rank,1:width]####otherwise, when rank is one, the data structure will change 
+  alpha [,1:rank] = t(equation$rlm$coefficients[1:rank,1:width])####otherwise, when rank is one, the data structure will change 
   oalpha <- qr.Q(qr(alpha),complete=TRUE) [ ,(rank+1):width] #### (width-rank) is the number of common trends
 
   beta= equation$beta
   obeta <- qr.Q(qr(beta),complete=TRUE)[,(rank+1):width] ### beta's structure is variable*rank
    
-  loading=obeta%*% ginv(t(obeta)%*%obeta)
+  loading=obeta%*% ginv(t(obeta)%*%obeta) #  Kasa's method and GG's method are different here.
    
   Pure.T= matrix(NA,(width-rank),(max-k) )
-  Pure.T[1:(width-rank),]= t(obeta) %*% t (data[begin:max,])
+  Pure.T[1:(width-rank),]= t(obeta) %*% t (data[begin:max,]) #  Kasa's method and GG's method are different here.
   Com.T= loading%*%Pure.T
   
   station.p = beta%*% ginv ( t(beta)%*%beta )%*% t(beta)   %*% t (data[begin:max,])
