@@ -1,4 +1,4 @@
-print.ComT <-
+"print.ComT" <-
 function(x,  ...){
   title <- paste(x$method)
   cat("According to ", title,"\n", sep="")
@@ -11,5 +11,4 @@ function(x,  ...){
   cat("\n")
   cat("Loading Vector:", "\n")
   print(x$loading.vector)
-  }
-
+  }
\ No newline at end of file
